<script setup>
import { ref, computed } from "vue";

const props = defineProps({
	offset: {
		type: Array,
		default() {
			return [0, 0];
		},
	},
  borderWidth: {
    type: [Number, String],
    default: 6,
  },
	width: {
		type: [Number, String],
		default: 142,
	},
	height: {
		type: [Number, String],
		default: 42,
	},
	color: {
		type: String,
		default: "url(#colorBorder0)",
	},
	fillColor: {
		type: String,
		default: '#989898',
	},
	tColor: {
		type: String,
		default: "#fff",
	},
	text: {
		type: [Number, String],
		default: "Text",
	},
	fontSize: {
		type: [Number, String],
		default: 16,
	},
	textAnchor: {
		type: String,
		validator: (v) => ["start", "middle", "end"].includes(v),
		default: "middle",
	},
});

const _width = computed(() => {
  return props.width - 2 * props.borderWidth;
});

const _height = computed(() => {
  return props.height - 2 * props.borderWidth;
});
</script>

<template>
  <g ref="g" :transform="'translate(' + offset.join(',') + ')'">
    <rect
      :width="width"
      :height="height"
      :stroke="color"
      :fill="fillColor"
      style="stroke-width: 1"
    />
    <rect
      :x="borderWidth"
      :y="borderWidth"
      :width="_width"
      :height="_height"
      stroke="url(#colorBorder0_reverse)"
      :fill="fillColor"
      style="stroke-width: 1"
    />
    <text
      :x="width / 2"
      :y="height / 2"
      :dy="fontSize / 2.6"
      :fill="tColor"
      :text-anchor="textAnchor"
      :font-size="fontSize"
      >{{ text }}</text
    >
  </g>
</template>

<style scoped lang="less"></style>
